"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hostBuilder = void 0;
const github_1 = __importDefault(require("./github"));
const gitlab_1 = __importDefault(require("./gitlab"));
const bitbucket_1 = __importDefault(require("./bitbucket"));
const vsts_1 = __importDefault(require("./vsts"));
const devops_1 = __importDefault(require("./devops"));
const error_1 = require("../error");
class HostBuilder {
    constructor(hosts) {
        this.hosts = hosts;
        this.hosts = hosts.length > 0 ? hosts : [new github_1.default(), new gitlab_1.default(), new bitbucket_1.default(), new vsts_1.default(), new devops_1.default()];
    }
    create(info, hostType) {
        const url = info.remoteUrl;
        for (const host of this.hosts) {
            if ((hostType === null || hostType === void 0 ? void 0 : hostType.toLowerCase()) === host.name.toLowerCase()) {
                return host;
            }
        }
        for (const host of this.hosts) {
            if (host.match(url)) {
                return host;
            }
        }
        throw new error_1.GitUrlError(`Can't find a matched host type for the url: ${url}. You may be able to specify the host type to match it.`);
    }
}
exports.hostBuilder = new HostBuilder([]);
//# sourceMappingURL=hostBuilder.js.map